# Information for test files

## MCS6A_short_10k_signal.lst

10000 shots recorded with MCS6A TDC.
Each shot contains exactly one count.
Counts were simulated with the DG.
Signal in channel 4.

## MCS8A_short_10k_signal.lst

10000 shots recorded with MCS8a TDC.
Empty lines / data point were subsequently
removed in order to conserve space for the
test case.
It was ensured that nothing changes due to this deleting of empties.
Counds were simulated with DG.
Signal in channel 9.
